@@ -11,13 +11,7 @@ import aiohttp
 
 from ._util import create_request
 from .const import MessageTypes
-from .errors import (
-    InvalidDeviceIDError,
-    InvalidLoginError,
-    NotOpenError,
-    ResponseError,
-    UnexpectedError,
-)
+from .errors import InvalidDeviceIDError, InvalidLoginError, NotOpenError, ResponseError
 from .ws import WebSocketMonitor
 
 
@@ -109,7 +103,7 @@ class Linear:
                 valid = False
 
             if not valid:
-                raise InvalidDeviceIDError("device_id must be a UUID.")
+                raise InvalidDeviceIDError()
             else:
                 device_id = device_id.upper()
 
@@ -126,12 +120,14 @@ class Linear:
 
         try:
             result = await asyncio.wait_for(future, timeout=10.0)
-        except asyncio.TimeoutError as e:
-            raise e
+        except asyncio.TimeoutError:
+            raise
 
         return result
 
-    async def _await_for_msg_type(self: Linear, msg_type: str) -> dict[str, Any]:
+    async def _await_for_msg_type(
+        self: Linear, msg_type: str, timeout: float = 10.0
+    ) -> dict[str, Any]:
         future: asyncio.Future[dict[str, Any]] = asyncio.Future()
 
         async def _got_resp(data: dict[str, Any]) -> None:
@@ -142,19 +138,22 @@ class Linear:
         self._internal_callback = _got_resp
 
         try:
-            result = await asyncio.wait_for(future, timeout=10.0)
-        except asyncio.TimeoutError as e:
-            raise e
+            result = await asyncio.wait_for(future, timeout=timeout)
+        except asyncio.TimeoutError:
+            raise
 
         return result
 
-    async def _await_for_dev_state_report(self: Linear) -> dict[str, Any]:
+    async def _await_for_dev_state_report(
+        self: Linear, device_id: str
+    ) -> dict[str, Any]:
         future: asyncio.Future[dict[str, Any]] = asyncio.Future()
 
         async def _got_resp(response: dict[str, Any]) -> None:
             if (
                 response["Type"] == MessageTypes.DEVICE_STATE.value
                 and response["Headers"]["Type"] == "Report"
+                and response["Headers"]["SendingDeviceID"] == "H/" + device_id
             ):
                 future.set_result(response)
                 self._internal_callback = None
@@ -163,8 +162,8 @@ class Linear:
 
         try:
             result = await asyncio.wait_for(future, timeout=10.0)
-        except asyncio.TimeoutError as e:
-            raise e
+        except asyncio.TimeoutError:
+            raise
 
         return result
 
@@ -177,7 +176,7 @@ class Linear:
 
     def _check_if_open(self: Linear) -> None:
         if not self.open:
-            raise NotOpenError("The WebSocket has not been opened. Call login() first.")
+            raise NotOpenError()
 
     async def _keepalive(self: Linear) -> None:
         while True:
@@ -272,8 +271,7 @@ class Linear:
         # Start keepalive task
         self._keepalive_task = asyncio.create_task(self._keepalive())
 
-        if ws is None:
-            raise UnexpectedError("ws is None when it should be.")
+        assert ws is not None
 
         self._monitor = ws_monitor
         self._ws = ws
@@ -287,11 +285,9 @@ class Linear:
             and response["Headers"]["UserID"] == ""
         ):
             if response["Headers"]["Reason"] == "InvalidLogin":
-                raise InvalidLoginError(
-                    "Login provided is invalid, please check the email and password"
-                )
+                raise InvalidLoginError()
 
-            raise InvalidLoginError("Login error: ", response["Headers"]["Reason"])
+            raise InvalidLoginError(response["Headers"]["Reason"])
 
         self._user_id = response["Headers"]["UserID"]
         self._user_email = response["Headers"]["UserEmail"]
@@ -542,6 +538,11 @@ class Linear:
 
         await self._ws.send_str(hello_request)
 
+        try:
+            await self._await_for_msg_type(MessageTypes.WELCOME.value, timeout=2.0)
+        except asyncio.TimeoutError:
+            pass
+
         state_request = create_request(
             MessageTypes.REQUEST_DEVICE_STATE,
             {
@@ -554,7 +555,7 @@ class Linear:
 
         await self._ws.send_str(state_request)
 
-        response = await self._await_for_dev_state_report()
+        response = await self._await_for_dev_state_report(device_id)
 
         subdev_props: dict[str, dict[str, str]] = {}
 
